@@ -16,12 +16,13 @@
 #ifndef K3B_EXTERNAL_BIN_MANAGER_H
 #define K3B_EXTERNAL_BIN_MANAGER_H
 
+#include "k3b_export.h"
+#include "k3bversion.h"
+
 #include <QMap>
 #include <QObject>
 #include <QString>
 #include <QStringList>
-#include "k3b_export.h"
-#include "k3bversion.h"
 
 class KConfigGroup;
 
@@ -38,13 +39,19 @@ namespace K3b {
     class LIBK3B_EXPORT ExternalBin
     {
     public:
-        ExternalBin( ExternalProgram* );
-        virtual ~ExternalBin() {}
+        ExternalBin( ExternalProgram& program, const QString& path );
+        virtual ~ExternalBin();
 
-        Version version;
-        QString path;
-        QString copyright;
+        void setNeedGroup( const QString& name );
+        const QString& needGroup() const;
 
+        void setVersion( const Version& version );
+        const Version& version() const;
+
+        void setCopyright( const QString& copyright );
+        const QString& copyright() const;
+
+        const QString& path() const;
         QString name() const;
         bool isEmpty() const;
         QStringList userParameters() const;
@@ -53,11 +60,11 @@ namespace K3b {
         bool hasFeature( const QString& ) const;
         void addFeature( const QString& );
 
-        ExternalProgram* program() const;
+        ExternalProgram& program() const;
 
     private:
-        QStringList m_features;
-        ExternalProgram* m_program;
+        class Private;
+        Private* const d;
     };
 
 
@@ -70,49 +77,47 @@ namespace K3b {
     class LIBK3B_EXPORT ExternalProgram
     {
     public:
-        ExternalProgram( const QString& name );
+        explicit ExternalProgram( const QString& name );
         virtual ~ExternalProgram();
 
         const ExternalBin* defaultBin() const;
         const ExternalBin* mostRecentBin() const;
 
         void addUserParameter( const QString& );
-        void setUserParameters( const QStringList& list ) { m_userParameters = list; }
+        void setUserParameters( const QStringList& list );
 
-        QStringList userParameters() const { return m_userParameters; }
-        QString name() const { return m_name; }
+        QStringList userParameters() const;
+        QString name() const;
 
         void addBin( ExternalBin* );
-        void clear() { m_bins.clear(); }
+        void clear();
         void setDefault( const ExternalBin* );
         void setDefault( const QString& path );
 
-        QList<const ExternalBin*> bins() const { return m_bins; }
+        QList<const ExternalBin*> bins() const;
 
         /**
          * this scans for the program in the given path,
-         * adds the found bin object to the list and returnes true.
+         * adds the found bin object to the list and returns true.
          * if nothing could be found false is returned.
          */
-        virtual bool scan( const QString& ) {return false;}//= 0;
+        virtual bool scan( const QString& ) = 0;
 
         /**
          * reimplement this if it does not make sense to have the user be able
          * to specify additional parameters
          */
-        virtual bool supportsUserParameters() const { return true; }
+        virtual bool supportsUserParameters() const;
 
         /**
          * Builds the path to the program from the \p dir and the \p programName.
-         * On Windows the .exe extension is added autoamtically.
+         * On Windows the .exe extension is added automatically.
          */
         static QString buildProgramPath( const QString& dir, const QString& programName );
 
     private:
-        QString m_name;
-        QStringList m_userParameters;
-        QList<const ExternalBin*> m_bins;
-        QString m_defaultBin;
+        class Private;
+        Private* const d;
     };
 
 
@@ -123,10 +128,10 @@ namespace K3b {
     class LIBK3B_EXPORT SimpleExternalProgram : public ExternalProgram
     {
     public:
-        SimpleExternalProgram( const QString& name );
-        virtual ~SimpleExternalProgram();
+        explicit SimpleExternalProgram( const QString& name );
+        ~SimpleExternalProgram() override;
 
-        virtual bool scan( const QString& path );
+        bool scan( const QString& path ) override;
 
         /**
          * Parses a version starting at \p pos by looking for the first digit
@@ -174,7 +179,7 @@ namespace K3b {
         virtual void parseFeatures( const QString& output, ExternalBin& bin ) const;
 
         /**
-         * @return the string preceeding the actual version string, used by
+         * @return the string preceding the actual version string, used by
          *         parseVersion() method. Default implementation returns name().
          */
         virtual QString versionIdentifier( const ExternalBin& bin ) const;
@@ -190,8 +195,8 @@ namespace K3b {
         Q_OBJECT
 
     public:
-        ExternalBinManager( QObject* parent = 0 );
-        ~ExternalBinManager();
+        explicit ExternalBinManager( QObject* parent = 0 );
+        ~ExternalBinManager() override;
 
         void search();
 
@@ -209,28 +214,25 @@ namespace K3b {
         bool foundBin( const QString& name );
         QString binPath( const QString& name );
         const ExternalBin* binObject( const QString& name );
+        QString binNeedGroup( const QString& name );
         const ExternalBin* mostRecentBinObject( const QString& name );
 
         ExternalProgram* program( const QString& ) const;
-        QMap<QString, ExternalProgram*> programs() const { return m_programs; }
+        QMap<QString, ExternalProgram*> programs() const;
 
         /** always extends the default searchpath */
         void setSearchPath( const QStringList& );
         void addSearchPath( const QString& );
         void loadDefaultSearchPath();
 
-        QStringList searchPath() const { return m_searchPath; }
+        QStringList searchPath() const;
 
         void addProgram( ExternalProgram* );
         void clear();
 
     private:
-        QMap<QString, ExternalProgram*> m_programs;
-        QStringList m_searchPath;
-
-        static QString m_noPath;  // used for binPath() to return const string
-
-        QString m_gatheredOutput;
+        class Private;
+        Private* const d;
     };
 }
 
